@@ -1,4 +1,5 @@
 from pathlib import Path
+from typing import Dict
 
 from cognite.airworkflow.model.project import Project, ProjectInfo
 from cognite.airworkflow.util import env, repoconfighelpers
@@ -8,6 +9,8 @@ working_path = env.get_env_value("PWD")
 ROOT_DIR = Path(working_path)
 FUNCTIONS_PATH = ROOT_DIR / "functions"
 IGNORE_MODELS_PATH = ROOT_DIR / ".ignore_models"
+SCHEDULEMANAGER_EXTERNAL_ID = "cognitedata/air-ds-infrastructure/schedulemanager:latest"
+AIR_FUNCTIONS_SCHEDULEMANAGER_EXTERNAL_ID = "cognitedata/air-functions/schedulemanager:latest"
 
 # Paths within a functions folder
 FUNCTION_REL_PATH = Path("function")
@@ -27,7 +30,15 @@ DEPLOYMENT_SCHEMA_PATH = SCHEMAS_PATH / "deployment-schema.yaml"
 CONFIG_SCHEMA_PATH = SCHEMAS_PATH / "config-schema.yaml"
 
 url_dict = repoconfighelpers.get_url_dict()
-if Project.NAME.value in url_dict:
-    PROJECT_TO_API_KEYS = {Project.NAME: ProjectInfo(Project.NAME, "AIR_API_KEY", str(url_dict[Project.NAME.value]))}
-else:
-    PROJECT_TO_API_KEYS = {Project.NAME: ProjectInfo(Project.NAME, "AIR_API_KEY")}
+PROJECTS_TO_API_KEYS: Dict = {}
+for project in Project.NAME.value:
+    if project in url_dict:
+        project_config = url_dict[project]
+        if isinstance(project_config, list):
+            PROJECT_TO_API_KEYS = ProjectInfo(project, project_config[1], str(project_config[0]))
+        else:
+            PROJECT_TO_API_KEYS = ProjectInfo(project, "AIR_API_KEY", str(project_config))
+
+    else:
+        PROJECT_TO_API_KEYS = ProjectInfo(project, "AIR_API_KEY")
+    PROJECTS_TO_API_KEYS[project] = PROJECT_TO_API_KEYS
