@@ -74,7 +74,14 @@ def handle_call_schedulemanager():
     _, project_to_config = get_master_config()
     for project in project_to_config:
         client = cdf.experimental_client(project)
-        client.functions.call(external_id=const.SCHEDULEMANAGER_EXTERNAL_ID, wait=False)
+        function_asset = client.functions.retrieve(external_id=const.SCHEDULEMANAGER_EXTERNAL_ID)
+        air_functions_asset = client.functions.retrieve(external_id=const.AIR_FUNCTIONS_SCHEDULEMANAGER_EXTERNAL_ID)
+        if function_asset is not None:
+            client.functions.call(external_id=const.SCHEDULEMANAGER_EXTERNAL_ID, wait=False)
+        elif air_functions_asset is not None:
+            client.functions.call(external_id=const.SCHEDULEMANAGER_EXTERNAL_ID, wait=False)
+        else:
+            raise ValueError("No schedule manager has been deployed in air-functions or air-ds-infrastructure!")
 
 
 def handle_check_deployment():
